
**`ABSESpy` 框架基于许多优秀的开源项目：**

| 包            | 版本              | 用途                                   |
|---------------|-------------------|----------------------------------------|
| python        | ">=3.9,<3.12"     | 开发使用的核心编程语言                 |
| netcdf4       | ">=1.6"           | 读写 NetCDF 和 HDF5 文件               |
| hydra-core    | "~1.3"            | 管理应用程序配置                       |
| mesa-geo      | ">=0.6"           | 创建空间显式的基于智能体的模型         |
| xarray        | "~2024"           | 处理标记的多维数组                     |
| fiona         | ">1.8"            | 读写矢量数据（shapefiles 等）          |
| loguru        | "~0.7"            | 更好的日志记录                         |
| rioxarray     | ">=0.13"          | 操作栅格数据和 xarray                  |
| pendulum      | "~2"              | 时间控制                               |
| geopandas     | "~0"              | shapefile 地理数据操作                 |

!!! Warning "警告"

    上表可能不是最新的，请参考 `pyproject.toml` 文件中的完整依赖项及其版本。

